CatPost

Struct CatPost 

pub struct CatPost { /* private fields */ }
Contains the attributes of a post in a catalog.

Implementations

Source

impl CatPost

pub fn no(&self) -> i32

Returns the numeric post ID.

pub fn resto(&self) -> i32

Returns the ID of the thread being replied to, or 0 for OP.

pub fn sticky(&self) -> Option<bool>

Returns true if the thread is stickied, or None otherwise.

pub fn closed(&self) -> Option<bool>

Returns true if the thread is closed, or None otherwise.

pub fn now(&self) -> &str

Returns the time of post creation as a formatted string.

pub fn time(&self) -> u64

Returns the UNIX timestamp of post creation.

pub fn name(&self) -> &str

Returns the name user posted with.

pub fn trip(&self) -> Option<&str>

Returns the tripcode if present, or None otherwise.

pub fn id(&self) -> Option<&str>

Returns the poster’s ID if present, or None otherwise.

pub fn capcode(&self) -> Option<&str>

Returns the capcode if present, or None otherwise.

pub fn country(&self) -> Option<&str>

Returns the poster’s country code if present, or None otherwise.

pub fn country_name(&self) -> Option<&str>

Returns the poster’s country name if present, or None otherwise.

pub fn sub(&self) -> Option<&str>

Returns the subject text if present, or None otherwise.

pub fn com(&self) -> &str

Returns the comment in HTML escaped form.

pub fn tim(&self) -> Option<i64>

Returns the timestamp of image upload if attachment exists, or None otherwise.

pub fn filename(&self) -> Option<&str>

Returns the filename as it appeared on the poster’s device if attachment exists, or None otherwise.

pub fn ext(&self) -> Option<&str>

Returns the filetype if attachment exists, or None otherwise.

pub fn fsize(&self) -> Option<i32>

Returns the size of uploaded file in bytes if attachment exists, or None otherwise.

pub fn md5(&self) -> Option<&str>

Returns the MD5 hash of file if attachment exists, or None otherwise.

pub fn w(&self) -> Option<i32>

Returns the image width if attachment exists, or None otherwise.

pub fn h(&self) -> Option<i32>

Returns the image height if attachment exists, or None otherwise.

pub fn tn_w(&self) -> Option<i32>

Returns the thumbnail image width if attachment exists, or None otherwise.

pub fn tn_h(&self) -> Option<i32>

Returns the thumbnail image height if attachment exists, or None otherwise.

pub fn filedeleted(&self) -> Option<i32>

Returns 1 if file was deleted from post, or None otherwise.

pub fn spoiler(&self) -> Option<i32>

Returns 1 if image was spoilered, or None otherwise.

pub fn custom_spoiler(&self) -> Option<i32>

Returns the custom spoiler ID for spoilered image, or None otherwise.

pub fn omitted_posts(&self) -> Option<i32>

Returns the number of replies minus number of previewed replies.

pub fn omitted_images(&self) -> Option<i32>

Returns the number of image replies minus number of previewed image replies.

pub fn replies(&self) -> Option<i32>

Returns the total number of replies to the thread.

pub fn images(&self) -> Option<i32>

Returns the total number of image replies to the thread.

pub fn bumplimit(&self) -> Option<bool>

Returns true if thread has reached bumplimit, or None otherwise.

pub fn imagelimit(&self) -> Option<bool>

Returns true if thread has reached imagelimit, or None otherwise.

pub fn last_modified(&self) -> Option<u64>

Returns the UNIX timestamp of last thread modification.

pub fn tag(&self) -> Option<&str>

Returns the category tag if present, or None otherwise.

pub fn semantic_url(&self) -> Option<&str>

Returns the SEO URL slug for thread.

pub fn since4pass(&self) -> Option<i32>

Returns the year a 4chan pass was bought if present, or None otherwise.

pub fn unique_ips(&self) -> Option<i32>

Returns the number of unique posters in the thread if present, or None otherwise.

pub fn m_img(&self) -> Option<bool>

Returns true if a mobile-optimized image exists for the post, or None otherwise.

pub fn last_replies(&self) -> Option<&[CatPost]>

Returns a slice of the most recent replies to the thread if present, or None otherwise.