pub struct CatPost { /* private fields */ }Expand description
Contains the attributes of a post in a catalog.
Implementations
Sourceimpl CatPost
impl CatPost
Sourcepub fn sticky(&self) -> Option<bool>
pub fn sticky(&self) -> Option<bool>
Returns true if the thread is stickied, or None otherwise.
Sourcepub fn country(&self) -> Option<&str>
pub fn country(&self) -> Option<&str>
Returns the poster’s country code if present, or None otherwise.
Sourcepub fn country_name(&self) -> Option<&str>
pub fn country_name(&self) -> Option<&str>
Returns the poster’s country name if present, or None otherwise.
Sourcepub fn tim(&self) -> Option<i64>
pub fn tim(&self) -> Option<i64>
Returns the timestamp of image upload if attachment exists, or None otherwise.
Sourcepub fn filename(&self) -> Option<&str>
pub fn filename(&self) -> Option<&str>
Returns the filename as it appeared on the poster’s device if attachment exists, or None otherwise.
Sourcepub fn ext(&self) -> Option<&str>
pub fn ext(&self) -> Option<&str>
Returns the filetype if attachment exists, or None otherwise.
Sourcepub fn fsize(&self) -> Option<i32>
pub fn fsize(&self) -> Option<i32>
Returns the size of uploaded file in bytes if attachment exists, or None otherwise.
Sourcepub fn md5(&self) -> Option<&str>
pub fn md5(&self) -> Option<&str>
Returns the MD5 hash of file if attachment exists, or None otherwise.
Sourcepub fn w(&self) -> Option<i32>
pub fn w(&self) -> Option<i32>
Returns the image width if attachment exists, or None otherwise.
Sourcepub fn h(&self) -> Option<i32>
pub fn h(&self) -> Option<i32>
Returns the image height if attachment exists, or None otherwise.
Sourcepub fn tn_w(&self) -> Option<i32>
pub fn tn_w(&self) -> Option<i32>
Returns the thumbnail image width if attachment exists, or None otherwise.
Sourcepub fn tn_h(&self) -> Option<i32>
pub fn tn_h(&self) -> Option<i32>
Returns the thumbnail image height if attachment exists, or None otherwise.
Sourcepub fn filedeleted(&self) -> Option<i32>
pub fn filedeleted(&self) -> Option<i32>
Returns 1 if file was deleted from post, or None otherwise.
Sourcepub fn custom_spoiler(&self) -> Option<i32>
pub fn custom_spoiler(&self) -> Option<i32>
Returns the custom spoiler ID for spoilered image, or None otherwise.
Sourcepub fn omitted_posts(&self) -> Option<i32>
pub fn omitted_posts(&self) -> Option<i32>
Returns the number of replies minus number of previewed replies.
Sourcepub fn omitted_images(&self) -> Option<i32>
pub fn omitted_images(&self) -> Option<i32>
Returns the number of image replies minus number of previewed image replies.
Sourcepub fn bumplimit(&self) -> Option<bool>
pub fn bumplimit(&self) -> Option<bool>
Returns true if thread has reached bumplimit, or None otherwise.
Sourcepub fn imagelimit(&self) -> Option<bool>
pub fn imagelimit(&self) -> Option<bool>
Returns true if thread has reached imagelimit, or None otherwise.
Sourcepub fn last_modified(&self) -> Option<u64>
pub fn last_modified(&self) -> Option<u64>
Returns the UNIX timestamp of last thread modification.
Sourcepub fn semantic_url(&self) -> Option<&str>
pub fn semantic_url(&self) -> Option<&str>
Returns the SEO URL slug for thread.
Sourcepub fn since4pass(&self) -> Option<i32>
pub fn since4pass(&self) -> Option<i32>
Returns the year a 4chan pass was bought if present, or None otherwise.
Sourcepub fn unique_ips(&self) -> Option<i32>
pub fn unique_ips(&self) -> Option<i32>
Returns the number of unique posters in the thread if present, or None otherwise.
Sourcepub fn m_img(&self) -> Option<bool>
pub fn m_img(&self) -> Option<bool>
Returns true if a mobile-optimized image exists for the post, or None otherwise.
Sourcepub fn last_replies(&self) -> Option<&[CatPost]>
pub fn last_replies(&self) -> Option<&[CatPost]>
Returns a slice of the most recent replies to the thread if present, or None otherwise.